summaryrefslogtreecommitdiff
path: root/pkgtools
diff options
context:
space:
mode:
authorgrant <grant>2003-04-11 21:27:43 +0000
committergrant <grant>2003-04-11 21:27:43 +0000
commitf075c35c5c0cfbcf2365aa305fa3e4ac6e46626a (patch)
tree6f975c643aa6a69460b16e4602caf41b5e9053e9 /pkgtools
parentf324891d29ace5dae368152c00c7600b2f80b34f (diff)
downloadpkgsrc-f075c35c5c0cfbcf2365aa305fa3e4ac6e46626a.tar.gz
sync with current:
darwin doesn't have uint64_t, use int64_t for now.
Diffstat (limited to 'pkgtools')
-rw-r--r--pkgtools/pkg_install/files/lib/lib.h.in4
-rw-r--r--pkgtools/pkg_install/files/lib/pen.c12
2 files changed, 8 insertions, 8 deletions
diff --git a/pkgtools/pkg_install/files/lib/lib.h.in b/pkgtools/pkg_install/files/lib/lib.h.in
index b29cd3c4d8d..bbeecbbc1ef 100644
--- a/pkgtools/pkg_install/files/lib/lib.h.in
+++ b/pkgtools/pkg_install/files/lib/lib.h.in
@@ -1,4 +1,4 @@
-/* $NetBSD: lib.h.in,v 1.5 2003/04/11 14:40:36 grant Exp $ */
+/* $NetBSD: lib.h.in,v 1.6 2003/04/11 21:27:43 grant Exp $ */
/* from FreeBSD Id: lib.h,v 1.25 1997/10/08 07:48:03 charnier Exp */
@@ -350,7 +350,7 @@ void cleanup(int);
char *make_playpen(char *, size_t, size_t);
char *where_playpen(void);
void leave_playpen(char *);
-uint64_t min_free(char *);
+int64_t min_free(char *);
void save_dirs(char **c, char **p);
void restore_dirs(char *c, char *p);
void show_version(void);
diff --git a/pkgtools/pkg_install/files/lib/pen.c b/pkgtools/pkg_install/files/lib/pen.c
index 17b98821555..e392ea25c0a 100644
--- a/pkgtools/pkg_install/files/lib/pen.c
+++ b/pkgtools/pkg_install/files/lib/pen.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pen.c,v 1.5 2003/04/11 14:40:36 grant Exp $ */
+/* $NetBSD: pen.c,v 1.6 2003/04/11 21:27:43 grant Exp $ */
#if 0
#include <sys/cdefs.h>
@@ -6,7 +6,7 @@
#if 0
static const char *rcsid = "from FreeBSD Id: pen.c,v 1.25 1997/10/08 07:48:12 charnier Exp";
#else
-__RCSID("$NetBSD: pen.c,v 1.5 2003/04/11 14:40:36 grant Exp $");
+__RCSID("$NetBSD: pen.c,v 1.6 2003/04/11 21:27:43 grant Exp $");
#endif
#endif
#endif
@@ -228,7 +228,7 @@ leave_playpen(char *save)
* in libc on 2.7 and 2.8, but not in 2.9)
*/
#if !defined(HAVE_STATFS) || (defined(HAVE_STATFS) && defined(HAVE_STATVFS) && !defined(__linux__) && !defined(__FreeBSD__))
-/* $NetBSD: pen.c,v 1.5 2003/04/11 14:40:36 grant Exp $ */
+/* $NetBSD: pen.c,v 1.6 2003/04/11 21:27:43 grant Exp $ */
/*-
* Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -403,10 +403,10 @@ fstatfs(fd, sfs)
/*
* Return free disk space (in bytes) on given file system.
* Returns size in a uint64_t since off_t isn't 64 bits on all
* operating systems.
*/
-uint64_t
+int64_t
min_free(char *tmpdir)
{
struct statfs buf;
@@ -415,5 +415,5 @@ min_free(char *tmpdir)
warn("statfs");
return -1;
}
- return (uint64_t) buf.f_bavail * (uint64_t) buf.f_bsize;
+ return (int64_t) buf.f_bavail * (int64_t) buf.f_bsize;
}
@@ -403,10 +403,10 @@ fstatfs(fd, sfs)
/*
* Return free disk space (in bytes) on given file system.
- * Returns size in a uint64_t since off_t isn't 64 bits on all
+ * Returns size in a int64_t since off_t isn't 64 bits on all
* operating systems.
*/